@@ -1,26 +1,30 @@
 import os
 import sys
 from itertools import product
+from pathlib import Path
 
 import cognite.airworkflow.constants as const
 from cognite.airworkflow.function_deployer import FunctionDeployer
-from cognite.airworkflow.master_config import get_master_config, get_parallel_deployment
+from cognite.airworkflow.master_config import get_master_config, get_parallel_deployment, write_dependency_yamls
 from cognite.airworkflow.model.schedule_assets import execute
 from cognite.airworkflow.model_asset_hierarchy import ModelAssetHierarchy
-from cognite.airworkflow.util import cdf, env, functions, github
+from cognite.airworkflow.util import cdf, env, functions, github, yaml
 
 
 def handle_asset_hierarchy():
-    _, project_to_config = get_master_config()
-
+    function_name, project = sys.argv[3].split("@")
+    function_name_path = Path(function_name)
+    function_path = const.FUNCTIONS_PATH / function_name_path / const.FUNCTION_REL_CONFIG_PATH
+    master_config = {
+        function_path.parent.parent: yaml.load_and_validate(function_path, const.CONFIG_SCHEMA_PATH, function_name)
+    }
+    write_dependency_yamls(master_config)
     if len(sys.argv) >= 2:
         airInfra = sys.argv[2] == "True"
     else:
         airInfra = False
-
-    for project, config in project_to_config.items():
-        print(f"Running Model Asset Hierarchy create/update for project {project}")
-        ModelAssetHierarchy(config, project, airInfra).create_or_update()
+    print(f"Running Model Asset Hierarchy create/update for project {project}")
+    ModelAssetHierarchy(master_config, project, airInfra).create_or_update()
 
 
 def handle_function_deployments():
@@ -31,7 +35,6 @@ def handle_function_deployments():
     assert (
         len(sys.argv) >= 3 and sys.argv[2]
     ), "Expected a function name passed as a command line argument, but got nothing"
-    # function_name = sys.argv[2].split("/")[-1] if "/" in sys.argv[2] else sys.argv[2]
     function_name, project_name = sys.argv[2].split("@")
     print(f"HANDLING {github_event_name} ON {github_ref} FOR FUNCTION {function_name}")
     for deployment in get_parallel_deployment(function_name, project_name):
@@ -71,7 +74,7 @@ def handle_call_schedulemanager():
     _, project_to_config = get_master_config()
     for project in project_to_config:
         client = cdf.experimental_client(project)
-        client.functions.call(external_id="cognitedata/air-functions/schedulemanager:latest", wait=False)
+        client.functions.call(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID, wait=False)
 
 
 def handle_check_deployment():
